@@ -180,6 +180,13 @@ class BaseBenchmark(ABC):
                 import flax  # noqa
             elif framework == 'spacy':
                 import spacy
+
+                # Ignore warnings from SpaCy. This has to be called after the
+                # import, as the __init__.py file of SpaCy sets the warning
+                # levels of SpaCy warning W036
+                import warnings
+                warnings.filterwarnings('ignore', module='spacy*')
+
         except ModuleNotFoundError:
             msg = (f'The model {model_id} is built using the {framework} '
                    f'framework which is not installed. Try installing the '
@@ -198,16 +205,16 @@ class BaseBenchmark(ABC):
 
             try:
                 config = AutoConfig.from_pretrained(model_id, **params)
+
+                model_cls = self._get_model_class(framework=framework)
+
+                model = model_cls.from_pretrained(model_id,
+                                                  config=config,
+                                                  cache_dir=self.cache_dir)
             except OSError:
                 raise InvalidBenchmark(f'The model {model_id} could not be '
                                        f'loaded from the HuggingFace hub.')
 
-            model_cls = self._get_model_class(framework=framework)
-
-            model = model_cls.from_pretrained(model_id,
-                                              config=config,
-                                              cache_dir=self.cache_dir)
-
             # If the model is a subclass of a RoBERTa model then we have to add
             # a prefix space to the tokens, by the way the model is
             # constructed.
@@ -492,31 +499,38 @@ class BaseBenchmark(ABC):
                 trainer.remove_callback(PrinterCallback)
 
                 # Finetune the model
-                if task == 'fill-mask':
-                    while True:
-                        try:
+                while True:
+                    try:
+                        if task == 'fill-mask':
                             trainer.train()
-                            break
-                        except RuntimeError as e:
-                            if not str(e).startswith('CUDA out of memory'):
-                                raise e
-                            bs = training_args.per_device_train_batch_size
-                            ga = training_args.gradient_accumulation_steps
-                            if bs == 1:
-                                raise RuntimeError('CUDA out of memory, even '
-                                                   'with a batch size of 1!')
-                            training_args.per_device_train_batch_size = bs // 2
-                            training_args.gradient_accumulation_steps = ga * 2
-                            trainer.args = training_args
 
-                # Log training metrics and save the state
-                train_metrics = trainer.evaluate(preprocessed_train,
-                                                 metric_key_prefix='train')
+                        # Log training metrics and save the state
+                        train_metrics = trainer.evaluate(
+                            preprocessed_train,
+                            metric_key_prefix='train'
+                        )
+
+                        # Log test metrics
+                        test_metrics = trainer.evaluate(
+                            preprocessed_test,
+                            metric_key_prefix='test'
+                        )
+
+                        break
+
+                    except RuntimeError as e:
+                        if not str(e).startswith('CUDA out of memory'):
+                            raise e
+                        bs = training_args.per_device_train_batch_size
+                        ga = training_args.gradient_accumulation_steps
+                        if bs == 1:
+                            raise RuntimeError('CUDA out of memory, even '
+                                               'with a batch size of 1!')
+                        training_args.per_device_train_batch_size = bs // 2
+                        training_args.gradient_accumulation_steps = ga * 2
+                        trainer.args = training_args
+
                 metrics['train'].append(train_metrics)
-
-                # Log test metrics
-                test_metrics = trainer.evaluate(preprocessed_test,
-                                                metric_key_prefix='test')
                 metrics['test'].append(test_metrics)
 
             self._log_metrics(metrics, model_id=model_id)
